function [sAIR] = f_AirDistance_AEO_analytical(...
                    N, v2min, ...
                    Sw,k_TO, ...
                    CD0clean, d_CD0_gear, d_CD0_flaps, CLmaxTO, ...
                    alpha, ...
                    m, ...
                    F0,BPR,b,vREL,di, ...
                    deltaT,rho,H) 

% vLOF  = v2min; 

g   = 9.80665;
W  = m*g;

% AR   = b^2/Sw;  % aspect ratio
% alphaRad = alpha*pi/180; 

% N    operating engines

p0     = 101325;
R      = 287.058;
kappa  = 1.4;
L      = 0.0065;
T0     = 288.15 + deltaT;

% Young 2008
p=p0*(1-H*L/T0)^(g/(R*L));
A=-0.4327*(p/p0).^2+1.3855*(p/p0)+0.0472 ;
X=0.1377*(p/p0).^2-0.4374*(p/p0)+1.3003;
Z=0.9106*(p/p0).^2-1.7736*(p/p0)+1.8697;
T=T0-0.0065*H;
c=sqrt(R*kappa*T);

... linear G-factor function: 
G = 0.061*BPR + 0.633; % gas generator factor:Young 2008 => A340, BPR=7.6
... determined in excel with 2 values of the original figure 
    
M = (v2min/c);
K1=  (((0.377*(1+BPR))  /   sqrt((1+0.82*BPR)*G)))*Z * (p/p0);
K2=  (0.23+0.19*sqrt(BPR)).*X.*p/p0 ;
F   = (N-1)*F0*( A - K1*(M)  +    K2*(M).^2);   %Bartels & Young (genauer - konservativer)

n = 1.15; 

R       = v2min^2/(g*(n-1));

CL2 = 1/(0.94*1.2)^2 * (CLmaxTO);
... derived from ratio v2 / vs1g = CL2 / CLmax
... v2^2          = 2w / (rho*Sw*CL2)
... vs1g^2        = 2w / (rho*Sw*CLmax)
... v2    = 1.2 vs = 1.2*0.94 vs1g
L = rho/2 *(v2min)^2 *CL2 * Sw; 

M     = v2min/c;

% k     = 1/(pi*e*AR);
% k_TO  = 1/(1/k+pi*AR*delta_e)
% CD0 = CD0clean + CDgear  + CDflaps + CDwm ;
CD0 = CD0clean + d_CD0_gear  + d_CD0_flaps ;
CD  = CD0 + k_TO*CL2^2 ;
% D = rho/2*(vLOF)^2*CD*Sw; 

% E=L/D;

% conversion ft => m
h_obstacle_ft  = 35;   % height in ft
h_obstacle_m   = h_obstacle_ft*0.3048;

hSC     = h_obstacle_m;

% R       = vLOF^2/(0.15*g);
% theta   = asin((F-D)/W);

% gamma     = (F-D)/W;
theta    = F/W-CD/CL2;

hTR     = R*(1-cos(theta));

if hTR  >= hSC 
  sTR   = sqrt(R^2-(R-hSC)^2);
  sCL   = 0;
else
  sTR   = R*sin(theta);
  sCL   = (hSC-hTR) / tan(theta) ;
end

sAIR    = sTR + sCL;  %total air distance

return